FunnelShift

Trait FunnelShift 

pub trait FunnelShift: Copy + 'static {
    // Required methods
    unsafe fn unchecked_funnel_shl(self, right: Self, shift: u32) -> Self;
    unsafe fn unchecked_funnel_shr(self, right: Self, shift: u32) -> Self;
}
🔬This is a nightly-only experimental API. (core_intrinsics_fallbacks)

Required Methods

unsafe fn unchecked_funnel_shl(self, right: Self, shift: u32) -> Self

🔬This is a nightly-only experimental API. (core_intrinsics_fallbacks)

We just need the trait indirection to handle different types since calling intrinsics with generics doesn’t work.

Safety

See super::unchecked_funnel_shl, with self corresponding to a and right corresponding to b.

unsafe fn unchecked_funnel_shr(self, right: Self, shift: u32) -> Self

🔬This is a nightly-only experimental API. (core_intrinsics_fallbacks)

We just need the trait indirection to handle different types since calling intrinsics with generics doesn’t work.

Safety

See super::unchecked_funnel_shr, with self corresponding to a and right corresponding to b.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors